betty.test_utils.ancestry package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.ancestry package

## Submodules

- betty.test_utils.ancestry.event_type module
  - `DummyEventType`
  - `EventTypeTestBase`
    - `EventTypeTestBase.test_comes_after()`
    - `EventTypeTestBase.test_comes_before()`

## Module contents

Test utilities for `betty.ancestry`.

class betty.test_utils.ancestry.DummyHasDate

  Bases: `HasDate`, `_LinkedDataObjectSchema`

  A dummy `betty.ancestry.HasDate` implementation.

class betty.test_utils.ancestry.DummyHasDescription

  Bases: `HasDescription`, `_LinkedDataObjectSchema`

  A dummy `betty.ancestry.HasDescription` implementation.

class betty.test_utils.ancestry.DummyHasLocale

  Bases: `HasLocale`, `_LinkedDataObjectSchema`

  A dummy `betty.ancestry.HasLocale` implementation.

class betty.test_utils.ancestry.DummyHasPrivacy

  Bases: `HasPrivacy`, `_LinkedDataObjectSchema`

  A dummy `betty.ancestry.HasPrivacy` implementation.